.. _user-guide:

User Guide
==========

.. toctree::
   :maxdepth: 2

   data_preparation
   behavior_classification
   behavior_discovery
   dimensionality_reduction
   self_supervised_tasks

Advanced
--------

.. toctree::
   :maxdepth: 2

   train_model
   fine_tuning
   prototype_calibration
   prototype_inference
